@@ -181,7 +181,7 @@ setMethod("mondate", "character", function(x, displayFormat = "keep", timeunits,
     isnax <- is.na(x)
     m <- match(TRUE, !isnax)
     if (is.na(m)) # all-NA input
-        return(mondate(rep(NA, length(x)), displayFormat = displayFormat, timeunits = timeunits, ...))
+        return(mondate(as.Date(rep(NA, length(x))), displayFormat = displayFormat, timeunits = timeunits, ...))
     # When no date conversion format is specified, find the first format that
     #   can convert the input to a Date
   mf <- missing(format)
@@ -228,6 +228,8 @@ setMethod("mondate", "character", function(x, displayFormat = "keep", timeunits,
   z
   })
 
+setMethod("mondate", "factor", function(x, displayFormat = "keep", timeunits, ...) mondate(as.character(x), displayFormat, timeunits, ...))
+
 # mondates can hold their shape if they have dim attributes
 setMethod("mondate", "array", function(x, displayFormat, timeunits, ...)
     structure(mondate(c(x), displayFormat, timeunits, ...), dim = dim(x), dimnames = dimnames(x)))
